<?php
namespace Teknisa\PLA\Modules\Prato\Controllers;

use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DTO;
use \Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use \Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DataSource\DataSet as DataSet_Source;

class ImportarReceita extends \Teknisa\GER\Controllers\TeknisaCrud {

    protected $pratoService;
    protected $prato;

    public function __construct(
        $crudService, $parameterBag,
        \Teknisa\PLA\Modules\Prato\Services\PratoService $pratoService,
        \Teknisa\PLA\Modules\Prato\Controllers\Prato $prato
    ) {
        parent::__construct($crudService, $parameterBag);
        $this->pratoService = $pratoService;
        $this->prato = $prato;
    }


    public function importarReceita(
        \Zeedhi\Framework\DTO\Request\Row $request,
        \Zeedhi\Framework\DTO\Response $response
    ){
        try {
            $this->pratoService->iniciaTransacao();

            $row = $request->getRow();
            $tpImportacao = $row['TIPO_IMPORT'];

            //DADOS DE ORIGEM
            $pratoO = $row['PRATO_O'];
            $cdFilAuxPratoO = $row['CDFILAUXPRAT_O'];
            $receitaO = $row['RECEITA_O'];

            if ($receitaO == "L") {
                $filialO = $row['CDFILIAL_O'];
            } else if ($receitaO == "S") {
                $filialO = $row['CDFILIAL_O'];
                $servicoO = $row['CDSERVFILI_O'];
            }

            //DADOS DE DESTINO
            $pratoD = $row['PRATO_D'];
            $cdFilAuxPratoD = $row['CDFILAUXPRAT_D'];
            $receitaD = $row['RECEITA_D'];

            if ($receitaD == "L") {
                $filialD = $row['CDFILIAL_D'];
            } else if ($receitaD == "S") {
                $filialD = $row['CDFILIAL_D'];
                $servicoD = $row['CDSERVFILI_D'];
            }

            if ($receitaD == 'P') {
                if ($receitaO == 'L') {
                    $this->importarReceitaLocalParaPadrao(
                        $tpImportacao, $pratoD, $cdFilAuxPratoD,
                        $pratoO, $cdFilAuxPratoO, $filialO, $row);
                } else if ($receitaO == 'S') {
                    $this->ImportarReceitaServicoParaPadrao(
                        $tpImportacao, $pratoD, $cdFilAuxPratoD,
                        $pratoO, $cdFilAuxPratoO, $filialO, $servicoO, $row);
                } else if ($receitaO == 'P') {
                    $this->importarReceitaPadraoParaPadrao(
                        $tpImportacao, $pratoD, $cdFilAuxPratoD,
                        $pratoO, $cdFilAuxPratoO, $row
                    );
                }
            } else if ($receitaD == 'L') {
                if ($receitaO == 'P') {
                    $this->importarReceitaPadraoParaLocal(
                        $tpImportacao, $pratoD, $cdFilAuxPratoD, $filialD,
                        $pratoO, $cdFilAuxPratoO, $row
                    );
                } else if ($receitaO == 'S') {
                    $this->importarReceitaServicoParaLocal(
                        $tpImportacao, $pratoD, $filialD, $cdFilAuxPratoD,
                        $pratoO, $cdFilAuxPratoO, $filialO, $servicoO, $row
                    );
                } else if ($receitaO == 'L') {
                    $this->importarReceitaLocalParaLocal(
                        $tpImportacao, $pratoD, $cdFilAuxPratoD, $filialD,
                        $pratoO, $cdFilAuxPratoO, $filialO, $row
                    );
                }
            } else if ($receitaD == 'S') {
                if ($receitaO == 'P') {
                    $this->importarReceitaPadraoParaServico(
                        $tpImportacao, $pratoD, $cdFilAuxPratoD, $filialD, $servicoD,
                        $pratoO, $cdFilAuxPratoO, $row
                    );
                } else if ($receitaO == 'L') {
                    $this->importarReceitaLocalParaServico(
                        $tpImportacao, $pratoD, $cdFilAuxPratoD, $filialD, $servicoD,
                        $pratoO, $cdFilAuxPratoO, $filialO, $row
                    );
                } else if ($receitaO == 'S') {
                    $this->importarReceitaServicoParaServico(
                        $tpImportacao, $pratoD, $filialD, $servicoD, $cdFilAuxPratoD,
                        $pratoO, $cdFilAuxPratoO, $filialO, $servicoO, $row
                    );
                }
            }

            $this->pratoService->commit();
            $response->addDataset(new DataSet_Source('IMPORTACAO', array(true)));
        } catch (\Exception $e) {
            $this->pratoService->rollback();
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 1));
        }
    }

    private function importarReceitaPadraoParaPadrao(
        $tpImportacao, $pratoD, $cdFilAuxPratoD,
        $pratoO, $cdFilAuxPratoO, $row
    ){
        try{
            // BUSCA RECEITA DE DESTINO
            $prodRec_D = $this->pratoService->retornaReceitaPadrao(
                $pratoD, $cdFilAuxPratoD
            );

            // BUSCA DADOS DA RECEITA DE DESTINO E EXCLUI
            $pratpadrD = $this->pratoService->retornaPratPadr(
                $pratoD, $cdFilAuxPratoD
            );
            $this->pratoService->excluiDadosReceita($pratpadrD);

            // BUSCA A RECEITA DE ORIGEM, QUE SERÁ COPIADA
            /** @var \Teknisa\Model\Planejamento\Entities\Pratpadr $pratpadrO */
            $pratpadrO = $this->pratoService->retornaPratPadr(
                $pratoO, $cdFilAuxPratoO
            );

            $idProdChill = null;
            $idFinal = null;
            $diasLim = null;
            $tpProdChill = null;
            $prodprod = null;

            if ($tpImportacao === 'A') { // ACRESCENTA
                if ($prodRec_D) {
                    foreach ($row['NOVOSPRODUTOS'] as $indice => $prodO) {
                        foreach ($prodRec_D as $prodD) {
                            if ($prodO['CDPRODUTO'] === $prodD->getCdproduto()) {
                                unset($row['NOVOSPRODUTOS'][$indice]);
                                continue 1;
                            }
                        }
                    }
                }
            } else { // SOBREPOE
                foreach ($prodRec_D as $produtos) {
                    $this->pratoService->excluiReceita($produtos);
                }

                if ($pratpadrO) {
                    $idProdChill = $pratpadrO->getIdprodchill();
                    $idFinal = $pratpadrO->getIdfinalpadr();
                    $diasLim = $pratpadrO->getQtlimsegpadr();
                    $tpProdChill = $pratpadrO->getIdtpprodchill();
                    $prodprod = $pratpadrO->getCdprodproducao();
                }
            }

            foreach ($row['NOVOSPRODUTOS'] as $novosProdutos) {
                $this->prato->insereReceita(
                    $novosProdutos['NRORG'], $cdFilAuxPratoD, $pratoD, null, null,
                    $novosProdutos['CDPRODUTO'], $novosProdutos['SGUNIDADEPROD'],
                    $novosProdutos['QUANTIDADE'], $novosProdutos['GANHOCOC'],
                    $novosProdutos['PERDALIMP'], $novosProdutos['QTREQUERIDA'],
                    $novosProdutos['QTUNIDEST'], $novosProdutos['APROVNUTRI'],
                    $novosProdutos['QTNUTRI'], $novosProdutos['QTBRUTA'],
                    $novosProdutos['HRTEMP'], $novosProdutos['BASE'],
                    $novosProdutos['QTFIXO'], $novosProdutos['ENTDIR'],
                    $novosProdutos['QTCOMPL'], $novosProdutos['TPREQ'],
                    $novosProdutos['APRESENT'], $novosProdutos['DIASLIM'],
                    $novosProdutos['DIASLIM']
                );
            }

            if ($pratpadrO){
                $this->prato->insereDadosPrato(
                    $cdFilAuxPratoD, $pratoD, null, null, $pratpadrO->getNrcorpriprat(),
                    $pratpadrO->getNrcorseqprat(), $pratpadrO->getNrcorauxprat(),
                    $pratpadrO->getQtpadraoprat(), $pratpadrO->getQtcontaiprat(),
                    $pratpadrO->getHrvalconprat(), $pratpadrO->getNmfantasiapr(),
                    $pratpadrO->getQtcarboprpad(), $pratpadrO->getQtlipidprpad(),
                    $pratpadrO->getQtproteprpad(), $pratpadrO->getQtcalorprpad(),
                    $pratpadrO->getQtalcooprpad(), $pratpadrO->getVrpeminpadr(),
                    $pratpadrO->getQtamostrpadr(), $prodprod, $diasLim, $idProdChill,
                    $tpProdChill, $idFinal, $pratpadrO->getNrorg()
                );
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    private function importarReceitaPadraoParaLocal(
        $tpImportacao, $pratoD, $cdFilAuxPratoD, $filialD,
        $pratoO, $cdFilAuxPratoO, $row
    ){
        try{
            // BUSCA RECEITA DE DESTINO
            $prodRec_D = $this->pratoService->retornaReceitaLocal(
                $pratoD, $cdFilAuxPratoD, $filialD
            );

            // BUSCA DADOS DA RECEITA DE DESTINO E EXCLUI
            $pratfiliD = $this->pratoService->retornaPratFili(
                $pratoD, $cdFilAuxPratoD, $filialD
            );
            $this->pratoService->excluiDadosReceita($pratfiliD);

            // BUSCA A RECEITA DE ORIGEM, QUE SERÁ COPIADA
            /** @var \Teknisa\Model\Planejamento\Entities\Pratpadr $pratpadrO */
            $pratpadrO = $this->pratoService->retornaPratPadr(
                $pratoO, $cdFilAuxPratoO
            );

            $idProdChill = null;
            $idFinal = null;
            $diasLim = null;
            $tpProdChill = null;
            $prodprod = null;

            if ($tpImportacao === 'A') { // ACRESCENTA
                if ($prodRec_D) {
                    // RETIRA OS PRODUTOS DA ORIGEM QUE JÁ EXISTEM NA RECEITA DE DESTINO
                    foreach ($row['NOVOSPRODUTOS'] as $indice => $prodO) {
                        foreach ($prodRec_D as $prodD) {
                            if ($prodO['CDPRODUTO'] === $prodD->getCdproduto()) {
                                unset($row['NOVOSPRODUTOS'][$indice]);
                                continue 1;
                            }
                        }
                    }
                }
            } else { // SOBREPOE
                // EXCLUI RECEITA DE DESTINO PARA INCLUIR OS DA ORIGEM
                foreach ($prodRec_D as $produtos) {
                    $this->pratoService->excluiReceita($produtos);
                }

                if ($pratpadrO) {
                    $idProdChill = $pratpadrO->getIdprodchill();
                    $idFinal = $pratpadrO->getIdfinalpadr();
                    $diasLim = $pratpadrO->getQtlimsegpadr();
                    $tpProdChill = $pratpadrO->getIdtpprodchill();
                    $prodprod = $pratpadrO->getCdprodproducao();
                }
            }

            foreach ($row['NOVOSPRODUTOS'] as $novosProdutos) {
                $this->prato->insereReceita(
                    $novosProdutos['NRORG'], $cdFilAuxPratoD, $pratoD, $filialD, null,
                    $novosProdutos['CDPRODUTO'], $novosProdutos['SGUNIDADEPROD'],
                    $novosProdutos['QUANTIDADE'], $novosProdutos['GANHOCOC'],
                    $novosProdutos['PERDALIMP'], $novosProdutos['QTREQUERIDA'],
                    $novosProdutos['QTUNIDEST'], $novosProdutos['APROVNUTRI'],
                    $novosProdutos['QTNUTRI'], $novosProdutos['QTBRUTA'],
                    $novosProdutos['HRTEMP'], $novosProdutos['BASE'],
                    $novosProdutos['QTFIXO'], $novosProdutos['ENTDIR'],
                    $novosProdutos['QTCOMPL'], $novosProdutos['TPREQ'],
                    $novosProdutos['APRESENT'], $novosProdutos['DIASLIM'],
                    $novosProdutos['DIASLIM']
                );
            }

            // INSERE DADOS DA RECEITA
            if ($pratpadrO){
                $this->prato->insereDadosPrato(
                    $cdFilAuxPratoD, $pratoD, $filialD, null, $pratpadrO->getNrcorpriprat(),
                    $pratpadrO->getNrcorseqprat(), $pratpadrO->getNrcorauxprat(),
                    $pratpadrO->getQtpadraoprat(), $pratpadrO->getQtcontaiprat(),
                    $pratpadrO->getHrvalconprat(), $pratpadrO->getNmfantasiapr(),
                    $pratpadrO->getQtcarboprpad(), $pratpadrO->getQtlipidprpad(),
                    $pratpadrO->getQtproteprpad(), $pratpadrO->getQtcalorprpad(),
                    $pratpadrO->getQtalcooprpad(), $pratpadrO->getVrpeminpadr(),
                    $pratpadrO->getQtamostrpadr(), $prodprod, $diasLim,
                    $idProdChill, $tpProdChill, $idFinal, $pratpadrO->getNrorg()
                );
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    private function importarReceitaPadraoParaServico(
        $tpImportacao, $pratoD, $cdFilAuxPratoD, $filialD, $servicoD,
        $pratoO, $cdFilAuxPratoO, $row
    ){
        try {
            // BUSCA RECEITA DE DESTINO
            $prodRec_D = $this->pratoService->retornaReceitaServico(
                $pratoD, $cdFilAuxPratoD, $filialD, $servicoD
            );

            // BUSCA DADOS DA RECEITA DE DESTINO E EXCLUI
            $pratservD = $this->pratoService->retornaPratServ(
                $pratoD, $cdFilAuxPratoD, $filialD, $servicoD
            );
            $this->pratoService->excluiDadosReceita($pratservD);

            // BUSCA A RECEITA DE ORIGEM, QUE SERÁ COPIADA
            /** @var \Teknisa\Model\Planejamento\Entities\Pratpadr $pratpadrO */
            $pratpadrO = $this->pratoService->retornaPratPadr(
                $pratoO, $cdFilAuxPratoO
            );

            $idProdChill = null;
            $idFinal = null;
            $diasLim = null;
            $tpProdChill = null;
            $prodprod = null;

            if ($tpImportacao === 'A') { // ACRESCENTA
                if ($prodRec_D) {
                    // RETIRA OS PRODUTOS DA ORIGEM QUE JÁ EXISTEM NA RECEITA DE DESTINO
                    foreach ($row['NOVOSPRODUTOS'] as $indice => $prodO) {
                        foreach ($prodRec_D as $prodD) {
                            if ($prodO['CDPRODUTO'] === $prodD->getCdproduto()
                            ) {
                                unset($row['NOVOSPRODUTOS'][$indice]);
                                continue 1;
                            }
                        }
                    }
                }
            } else { // SOBREPOE
                // EXCLUI RECEITA DE DESTINO PARA INCLUIR OS DA ORIGEM
                foreach ($prodRec_D as $produtos) {
                    $this->pratoService->excluiReceita($produtos);
                }

                if ($pratpadrO) {
                    $idProdChill = $pratpadrO->getIdprodchill();
                    $idFinal = $pratpadrO->getIdfinalpadr();
                    $diasLim = $pratpadrO->getQtlimsegpadr();
                    $tpProdChill = $pratpadrO->getIdtpprodchill();
                    $prodprod = $pratpadrO->getCdprodproducao();
                }
            }

            //INSERE PRODUTOS NA RECEITA
            foreach ($row['NOVOSPRODUTOS'] as $novosProdutos) {
                $this->prato->insereReceita(
                    $novosProdutos['NRORG'], $cdFilAuxPratoD, $pratoD, $filialD, $servicoD,
                    $novosProdutos['CDPRODUTO'], $novosProdutos['SGUNIDADEPROD'],
                    $novosProdutos['QUANTIDADE'], $novosProdutos['GANHOCOC'],
                    $novosProdutos['PERDALIMP'], $novosProdutos['QTREQUERIDA'],
                    $novosProdutos['QTUNIDEST'], $novosProdutos['APROVNUTRI'],
                    $novosProdutos['QTNUTRI'], $novosProdutos['QTBRUTA'],
                    $novosProdutos['HRTEMP'], $novosProdutos['BASE'],
                    $novosProdutos['QTFIXO'], $novosProdutos['ENTDIR'],
                    $novosProdutos['QTCOMPL'], $novosProdutos['TPREQ'],
                    $novosProdutos['APRESENT'], $novosProdutos['DIASLIM'],
                    $novosProdutos['DIASLIM']
                );
            }

            // INSERE DADOS DA RECEITA
            if ($pratpadrO) {
                $this->prato->insereDadosPrato(
                    $cdFilAuxPratoD, $pratoD, $filialD, $servicoD, $pratpadrO->getNrcorpriprat(),
                    $pratpadrO->getNrcorseqprat(), $pratpadrO->getNrcorauxprat(),
                    $pratpadrO->getQtpadraoprat(), $pratpadrO->getQtcontaiprat(),
                    $pratpadrO->getHrvalconprat(), $pratpadrO->getNmfantasiapr(),
                    $pratpadrO->getQtcarboprpad(), $pratpadrO->getQtlipidprpad(),
                    $pratpadrO->getQtproteprpad(), $pratpadrO->getQtcalorprpad(),
                    $pratpadrO->getQtalcooprpad(), $pratpadrO->getVrpeminpadr(),
                    $pratpadrO->getQtamostrpadr(), $prodprod, $diasLim,
                    $idProdChill, $tpProdChill, $idFinal, $pratpadrO->getNrorg()
                );
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    private function importarReceitaLocalParaPadrao(
        $tpImportacao, $pratoD, $cdFilAuxPratoD,
        $pratoO, $cdFilAuxPratoO, $filialO, $row
    ){
        try{
            // BUSCA RECEITA DE DESTINO
            $prodRec_D = $this->pratoService->retornaReceitaPadrao(
                $pratoD, $cdFilAuxPratoD
            );

            // BUSCA DADOS DA RECEITA DE DESTINO E EXCLUI
            $pratpadrD = $this->pratoService->retornaPratPadr(
                $pratoD, $cdFilAuxPratoD
            );
            $this->pratoService->excluiDadosReceita($pratpadrD);

            // BUSCA A RECEITA DE ORIGEM, QUE SERÁ COPIADA
            /** @var \Teknisa\Model\Planejamento\Entities\Pratfili $pratfiliO */
            $pratfiliO = $this->pratoService->retornaPratFili(
                $pratoO, $cdFilAuxPratoO, $filialO
            );

            $idProdChill = null;
            $idFinal = null;
            $diasLim = null;
            $tpProdChill = null;
            $prodprod = null;

            if ($tpImportacao === 'A') { // ACRESCENTA
                if ($prodRec_D) {
                    foreach ($row['NOVOSPRODUTOS'] as $indice => $prodO) {
                        foreach ($prodRec_D as $prodD) {
                            if ($prodO['CDPRODUTO'] === $prodD->getCdproduto()) {
                                unset($row['NOVOSPRODUTOS'][$indice]);
                                continue 1;
                            }
                        }
                    }
                }
            } else { // SOBREPOE
                foreach ($prodRec_D as $produtos) {
                    $this->pratoService->excluiReceita($produtos);
                }

                if ($pratfiliO) {
                    $idProdChill = $pratfiliO->getIdprodchill();
                    $idFinal = $pratfiliO->getIdfinalfili();
                    $diasLim = $pratfiliO->getQtlimsegfili();
                    $tpProdChill = $pratfiliO->getIdtpprodchill();
                    $prodprod = $pratfiliO->getCdprodproducao();
                }
            }

            foreach ($row['NOVOSPRODUTOS'] as $novosProdutos) {
                $this->prato->insereReceita(
                    $novosProdutos['NRORG'], $cdFilAuxPratoD, $pratoD, null, null,
                    $novosProdutos['CDPRODUTO'], $novosProdutos['SGUNIDADEPROD'],
                    $novosProdutos['QUANTIDADE'], $novosProdutos['GANHOCOC'],
                    $novosProdutos['PERDALIMP'], $novosProdutos['QTREQUERIDA'],
                    $novosProdutos['QTUNIDEST'], $novosProdutos['APROVNUTRI'],
                    $novosProdutos['QTNUTRI'], $novosProdutos['QTBRUTA'],
                    $novosProdutos['HRTEMP'], $novosProdutos['BASE'],
                    $novosProdutos['QTFIXO'], $novosProdutos['ENTDIR'],
                    $novosProdutos['QTCOMPL'], $novosProdutos['TPREQ'],
                    $novosProdutos['APRESENT'], $novosProdutos['DIASLIM'],
                    $novosProdutos['DIASLIM']
                );
            }

            if ($pratfiliO){
                $this->prato->insereDadosPrato(
                    $cdFilAuxPratoD, $pratoD, null, null, $pratfiliO->getNrcorprifili(),
                    $pratfiliO->getNrcorseqfili(), $pratfiliO->getNrcorauxfili(),
                    $pratfiliO->getQtpadraofili(), $pratfiliO->getQtcontaifili(),
                    $pratfiliO->getHrvalconfili(), $pratfiliO->getNmfantasiapf(),
                    $pratfiliO->getQtcarboprfil(), $pratfiliO->getQtlipidprfil(),
                    $pratfiliO->getQtproteprfil(), $pratfiliO->getQtcalorprfil(),
                    $pratfiliO->getQtalcooprfil(), $pratfiliO->getVrpeminfili(),
                    $pratfiliO->getQtamostrfili(), $prodprod, $diasLim,
                    $idProdChill, $tpProdChill, $idFinal, $pratfiliO->getNrorg()
                );
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    private function importarReceitaLocalParaLocal(
        $tpImportacao, $pratoD, $cdFilAuxPratoD, $filialD,
        $pratoO, $cdFilAuxPratoO, $filialO, $row
    ){
        try{
            // BUSCA RECEITA DE DESTINO
            $prodRec_D = $this->pratoService->retornaReceitaLocal(
                $pratoD, $cdFilAuxPratoD, $filialD
            );

            // BUSCA DADOS DA RECEITA DE DESTINO E EXCLUI
            $pratpadrD = $this->pratoService->retornaPratFili(
                $pratoD, $cdFilAuxPratoD, $filialD
            );
            $this->pratoService->excluiDadosReceita($pratpadrD);

            // BUSCA A RECEITA DE ORIGEM, QUE SERÁ COPIADA
            /** @var \Teknisa\Model\Planejamento\Entities\Pratfili $pratfiliO */
            $pratfiliO = $this->pratoService->retornaPratFili(
                $pratoO, $cdFilAuxPratoO, $filialO
            );

            $idProdChill = null;
            $idFinal = null;
            $diasLim = null;
            $tpProdChill = null;
            $prodprod = null;

            if ($tpImportacao === 'A') { // ACRESCENTA
                if ($prodRec_D) {
                    foreach ($row['NOVOSPRODUTOS'] as $indice => $prodO) {
                        foreach ($prodRec_D as $prodD) {
                            if ($prodO['CDPRODUTO'] === $prodD->getCdproduto()) {
                                unset($row['NOVOSPRODUTOS'][$indice]);
                                continue 1;
                            }
                        }
                    }
                }
            } else { // SOBREPOE
                foreach ($prodRec_D as $produtos) {
                    $this->pratoService->excluiReceita($produtos);
                }

                if ($pratfiliO) {
                    $idProdChill = $pratfiliO->getIdprodchill();
                    $idFinal = $pratfiliO->getIdfinalfili();
                    $diasLim = $pratfiliO->getQtlimsegfili();
                    $tpProdChill = $pratfiliO->getIdtpprodchill();
                    $prodprod = $pratfiliO->getCdprodproducao();
                }
            }

            foreach ($row['NOVOSPRODUTOS'] as $novosProdutos) {
                $this->prato->insereReceita(
                    $novosProdutos['NRORG'], $cdFilAuxPratoD, $pratoD, $filialD, null,
                    $novosProdutos['CDPRODUTO'], $novosProdutos['SGUNIDADEPROD'],
                    $novosProdutos['QUANTIDADE'], $novosProdutos['GANHOCOC'],
                    $novosProdutos['PERDALIMP'], $novosProdutos['QTREQUERIDA'],
                    $novosProdutos['QTUNIDEST'], $novosProdutos['APROVNUTRI'],
                    $novosProdutos['QTNUTRI'], $novosProdutos['QTBRUTA'],
                    $novosProdutos['HRTEMP'], $novosProdutos['BASE'],
                    $novosProdutos['QTFIXO'], $novosProdutos['ENTDIR'],
                    $novosProdutos['QTCOMPL'], $novosProdutos['TPREQ'],
                    $novosProdutos['APRESENT'], $novosProdutos['DIASLIM'],
                    $novosProdutos['DIASLIM']
                );
            }

            if ($pratfiliO){
                $this->prato->insereDadosPrato(
                    $cdFilAuxPratoD, $pratoD, $filialD, null, $pratfiliO->getNrcorprifili(),
                    $pratfiliO->getNrcorseqfili(), $pratfiliO->getNrcorauxfili(),
                    $pratfiliO->getQtpadraofili(), $pratfiliO->getQtcontaifili(),
                    $pratfiliO->getHrvalconfili(), $pratfiliO->getNmfantasiapf(),
                    $pratfiliO->getQtcarboprfil(), $pratfiliO->getQtlipidprfil(),
                    $pratfiliO->getQtproteprfil(), $pratfiliO->getQtcalorprfil(),
                    $pratfiliO->getQtalcooprfil(), $pratfiliO->getVrpeminfili(),
                    $pratfiliO->getQtamostrfili(), $prodprod, $diasLim,
                    $idProdChill, $tpProdChill, $idFinal, $pratfiliO->getNrorg()
                );
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    private function importarReceitaLocalParaServico(
        $tpImportacao, $pratoD, $cdFilAuxPratoD, $filialD, $servicoD,
        $pratoO, $cdFilAuxPratoO, $filialO, $row
    ){
        try{
            // BUSCA RECEITA DE DESTINO
            $prodRec_D = $this->pratoService->retornaReceitaServico(
                $pratoD, $cdFilAuxPratoD, $filialD, $servicoD
            );

            // BUSCA DADOS DA RECEITA DE DESTINO E EXCLUI
            $pratpadrD = $this->pratoService->retornaPratServ(
                $pratoD, $cdFilAuxPratoD, $filialD, $servicoD
            );
            $this->pratoService->excluiDadosReceita($pratpadrD);

            // BUSCA A RECEITA DE ORIGEM, QUE SERÁ COPIADA
            /** @var \Teknisa\Model\Planejamento\Entities\Pratfili $pratfiliO */
            $pratfiliO = $this->pratoService->retornaPratFili(
                $pratoO, $cdFilAuxPratoO, $filialO
            );

            $idProdChill = null;
            $idFinal = null;
            $diasLim = null;
            $tpProdChill = null;
            $prodprod = null;

            if ($tpImportacao === 'A') { // ACRESCENTA
                if ($prodRec_D) {
                    foreach ($row['NOVOSPRODUTOS'] as $indice => $prodO) {
                        foreach ($prodRec_D as $prodD) {
                            if ($prodO['CDPRODUTO'] === $prodD->getCdproduto()) {
                                unset($row['NOVOSPRODUTOS'][$indice]);
                                continue 1;
                            }
                        }
                    }
                }
            } else { // SOBREPOE
                foreach ($prodRec_D as $produtos) {
                    $this->pratoService->excluiReceita($produtos);
                }

                if ($pratfiliO) {
                    $idProdChill = $pratfiliO->getIdprodchill();
                    $idFinal = $pratfiliO->getIdfinalfili();
                    $diasLim = $pratfiliO->getQtlimsegfili();
                    $tpProdChill = $pratfiliO->getIdtpprodchill();
                    $prodprod = $pratfiliO->getCdprodproducao();
                }
            }

            foreach ($row['NOVOSPRODUTOS'] as $novosProdutos) {
                $this->prato->insereReceita(
                    $novosProdutos['NRORG'], $cdFilAuxPratoD, $pratoD, $filialD, $servicoD,
                    $novosProdutos['CDPRODUTO'], $novosProdutos['SGUNIDADEPROD'],
                    $novosProdutos['QUANTIDADE'], $novosProdutos['GANHOCOC'],
                    $novosProdutos['PERDALIMP'], $novosProdutos['QTREQUERIDA'],
                    $novosProdutos['QTUNIDEST'], $novosProdutos['APROVNUTRI'],
                    $novosProdutos['QTNUTRI'], $novosProdutos['QTBRUTA'],
                    $novosProdutos['HRTEMP'], $novosProdutos['BASE'],
                    $novosProdutos['QTFIXO'], $novosProdutos['ENTDIR'],
                    $novosProdutos['QTCOMPL'], $novosProdutos['TPREQ'],
                    $novosProdutos['APRESENT'], $novosProdutos['DIASLIM'],
                    $novosProdutos['DIASLIM']
                );
            }

            if ($pratfiliO){
                $this->prato->insereDadosPrato(
                    $cdFilAuxPratoD, $pratoD, $filialD, $servicoD, $pratfiliO->getNrcorprifili(),
                    $pratfiliO->getNrcorseqfili(), $pratfiliO->getNrcorauxfili(),
                    $pratfiliO->getQtpadraofili(), $pratfiliO->getQtcontaifili(),
                    $pratfiliO->getHrvalconfili(), $pratfiliO->getNmfantasiapf(),
                    $pratfiliO->getQtcarboprfil(), $pratfiliO->getQtlipidprfil(),
                    $pratfiliO->getQtproteprfil(), $pratfiliO->getQtcalorprfil(),
                    $pratfiliO->getQtalcooprfil(), $pratfiliO->getVrpeminfili(),
                    $pratfiliO->getQtamostrfili(), $prodprod, $diasLim,
                    $idProdChill, $tpProdChill, $idFinal, $pratfiliO->getNrorg()
                );
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    private function importarReceitaServicoParaPadrao(
        $tpImportacao, $pratoD, $cdFilAuxPratoD,
        $pratoO, $cdFilAuxPratoO, $filialO, $servicoO, $row
    ){
        try{
            // BUSCA RECEITA DE DESTINO
            $prodRec_D = $this->pratoService->retornaReceitaPadrao(
                $pratoD, $cdFilAuxPratoD
            );

            // BUSCA DADOS DA RECEITA DE DESTINO E EXCLUI
            $pratpadrD = $this->pratoService->retornaPratPadr(
                $pratoD, $cdFilAuxPratoD
            );
            $this->pratoService->excluiDadosReceita($pratpadrD);

            // BUSCA A RECEITA DE ORIGEM, QUE SERÁ COPIADA
            /** @var \Teknisa\Model\Planejamento\Entities\Pratserv $pratservO */
            $pratservO = $this->pratoService->retornaPratServ(
                $pratoO, $cdFilAuxPratoO, $filialO, $servicoO
            );

            $idProdChill = null;
            $idFinal = null;
            $diasLim = null;
            $tpProdChill = null;
            $prodprod = null;

            if ($tpImportacao === 'A') { // ACRESCENTA
                if ($prodRec_D) {
                    foreach ($row['NOVOSPRODUTOS'] as $indice => $prodO) {
                        foreach ($prodRec_D as $prodD) {
                            if ($prodO['CDPRODUTO'] === $prodD->getCdproduto()) {
                                unset($row['NOVOSPRODUTOS'][$indice]);
                                continue 1;
                            }
                        }
                    }
                }
            } else { // SOBREPOE
                foreach ($prodRec_D as $produtos) {
                    $this->pratoService->excluiReceita($produtos);
                }

                if ($pratservO) {
                    $idProdChill = $pratservO->getIdprodchill();
                    $idFinal = $pratservO->getIdfinalserv();
                    $diasLim = $pratservO->getQtlimsegserv();
                    $tpProdChill = $pratservO->getIdtpprodchill();
                    $prodprod = $pratservO->getCdprodproducao();
                }
            }

            foreach ($row['NOVOSPRODUTOS'] as $novosProdutos) {
                $this->prato->insereReceita(
                    $novosProdutos['NRORG'], $cdFilAuxPratoD, $pratoD, null, null,
                    $novosProdutos['CDPRODUTO'], $novosProdutos['SGUNIDADEPROD'],
                    $novosProdutos['QUANTIDADE'], $novosProdutos['GANHOCOC'],
                    $novosProdutos['PERDALIMP'], $novosProdutos['QTREQUERIDA'],
                    $novosProdutos['QTUNIDEST'], $novosProdutos['APROVNUTRI'],
                    $novosProdutos['QTNUTRI'], $novosProdutos['QTBRUTA'],
                    $novosProdutos['HRTEMP'], $novosProdutos['BASE'],
                    $novosProdutos['QTFIXO'], $novosProdutos['ENTDIR'],
                    $novosProdutos['QTCOMPL'], $novosProdutos['TPREQ'],
                    $novosProdutos['APRESENT'], $novosProdutos['DIASLIM'],
                    $novosProdutos['DIASLIM']
                );
            }

            if ($pratservO){
                $this->prato->insereDadosPrato(
                    $cdFilAuxPratoD, $pratoD, null, null, $pratservO->getNrcorpriserv(),
                    $pratservO->getNrcorseqserv(), $pratservO->getNrcorauxserv(),
                    $pratservO->getQtpadraoserv(), $pratservO->getQtcontaiserv(),
                    $pratservO->getHrvalconserv(), $pratservO->getNmfantasiase(),
                    $pratservO->getQtcarboprser(), $pratservO->getQtlipidprser(),
                    $pratservO->getQtproteprser(), $pratservO->getQtcalorprser(),
                    $pratservO->getQtalcooprser(), $pratservO->getVrpeminserv(),
                    $pratservO->getQtamostrserv(), $prodprod, $diasLim,
                    $idProdChill, $tpProdChill, $idFinal, $pratservO->getNrorg()
                );
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    private function importarReceitaServicoParaLocal(
        $tpImportacao, $pratoD, $filialD, $cdFilAuxPratoD,
        $pratoO, $cdFilAuxPratoO, $filialO, $servicoO, $row
    ){
        try{
            // BUSCA RECEITA DE DESTINO
            $prodRec_D = $this->pratoService->retornaReceitaLocal(
                $pratoD, $cdFilAuxPratoD, $filialD
            );

            // BUSCA DADOS DA RECEITA DE DESTINO E EXCLUI
            $pratfiliD = $this->pratoService->retornaPratFili(
                $pratoD, $cdFilAuxPratoD, $filialD
            );
            $this->pratoService->excluiDadosReceita($pratfiliD);

            // BUSCA A RECEITA DE ORIGEM, QUE SERÁ COPIADA
            /** @var \Teknisa\Model\Planejamento\Entities\Pratserv $pratservO */
            $pratservO = $this->pratoService->retornaPratServ(
                $pratoO, $cdFilAuxPratoO, $filialO, $servicoO
            );

            $idProdChill = null;
            $idFinal = null;
            $diasLim = null;
            $tpProdChill = null;
            $prodprod = null;

            if ($tpImportacao === 'A') { // ACRESCENTA
                if ($prodRec_D) {
                    foreach ($row['NOVOSPRODUTOS'] as $indice => $prodO) {
                        foreach ($prodRec_D as $prodD) {
                            if ($prodO['CDPRODUTO'] === $prodD->getCdproduto()) {
                                unset($row['NOVOSPRODUTOS'][$indice]);
                                continue 1;
                            }
                        }
                    }
                }
            } else { // SOBREPOE
                foreach ($prodRec_D as $produtos) {
                    $this->pratoService->excluiReceita($produtos);
                }

                if ($pratservO) {
                    $idProdChill = $pratservO->getIdprodchill();
                    $idFinal = $pratservO->getIdfinalserv();
                    $diasLim = $pratservO->getQtlimsegserv();
                    $tpProdChill = $pratservO->getIdtpprodchill();
                    $prodprod = $pratservO->getCdprodproducao();
                }
            }

            foreach ($row['NOVOSPRODUTOS'] as $novosProdutos) {
                $this->prato->insereReceita(
                    $novosProdutos['NRORG'], $cdFilAuxPratoD, $pratoD, $filialD, null,
                    $novosProdutos['CDPRODUTO'], $novosProdutos['SGUNIDADEPROD'],
                    $novosProdutos['QUANTIDADE'], $novosProdutos['GANHOCOC'],
                    $novosProdutos['PERDALIMP'], $novosProdutos['QTREQUERIDA'],
                    $novosProdutos['QTUNIDEST'], $novosProdutos['APROVNUTRI'],
                    $novosProdutos['QTNUTRI'], $novosProdutos['QTBRUTA'],
                    $novosProdutos['HRTEMP'], $novosProdutos['BASE'],
                    $novosProdutos['QTFIXO'], $novosProdutos['ENTDIR'],
                    $novosProdutos['QTCOMPL'], $novosProdutos['TPREQ'],
                    $novosProdutos['APRESENT'], $novosProdutos['DIASLIM'],
                    $novosProdutos['DIASLIM']
                );
            }

            if ($pratservO){
                $this->prato->insereDadosPrato(
                    $cdFilAuxPratoD, $pratoD, $filialD, null, $pratservO->getNrcorpriserv(),
                    $pratservO->getNrcorseqserv(), $pratservO->getNrcorauxserv(),
                    $pratservO->getQtpadraoserv(), $pratservO->getQtcontaiserv(),
                    $pratservO->getHrvalconserv(), $pratservO->getNmfantasiase(),
                    $pratservO->getQtcarboprser(), $pratservO->getQtlipidprser(),
                    $pratservO->getQtproteprser(), $pratservO->getQtcalorprser(),
                    $pratservO->getQtalcooprser(), $pratservO->getVrpeminserv(),
                    $pratservO->getQtamostrserv(), $prodprod, $diasLim,
                    $idProdChill, $tpProdChill, $idFinal, $pratservO->getNrorg()
                );
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    private function importarReceitaServicoParaServico(
        $tpImportacao, $pratoD, $filialD, $servicoD, $cdFilAuxPratoD,
        $pratoO, $cdFilAuxPratoO, $filialO, $servicoO, $row
    ){
        try{
            // BUSCA RECEITA DE DESTINO
            $prodRec_D = $this->pratoService->retornaReceitaServico(
                $pratoD, $cdFilAuxPratoD, $filialD, $servicoD
            );

            // BUSCA DADOS DA RECEITA DE DESTINO E EXCLUI
            $pratservD = $this->pratoService->retornaPratServ(
                $pratoD, $cdFilAuxPratoD, $filialD, $servicoD
            );
            $this->pratoService->excluiDadosReceita($pratservD);

            // BUSCA A RECEITA DE ORIGEM, QUE SERÁ COPIADA
            /** @var \Teknisa\Model\Planejamento\Entities\Pratserv $pratservO */
            $pratservO = $this->pratoService->retornaPratServ(
                $pratoO, $cdFilAuxPratoO, $filialO, $servicoO
            );

            $idProdChill = null;
            $idFinal = null;
            $diasLim = null;
            $tpProdChill = null;
            $prodprod = null;

            if ($tpImportacao === 'A') { // ACRESCENTA
                if ($prodRec_D) {
                    foreach ($row['NOVOSPRODUTOS'] as $indice => $prodO) {
                        foreach ($prodRec_D as $prodD) {
                            if ($prodO['CDPRODUTO'] === $prodD->getCdproduto()) {
                                unset($row['NOVOSPRODUTOS'][$indice]);
                                continue 1;
                            }
                        }
                    }
                }
            } else { // SOBREPOE
                foreach ($prodRec_D as $produtos) {
                    $this->pratoService->excluiReceita($produtos);
                }

                if ($pratservO) {
                    $idProdChill = $pratservO->getIdprodchill();
                    $idFinal = $pratservO->getIdfinalserv();
                    $diasLim = $pratservO->getQtlimsegserv();
                    $tpProdChill = $pratservO->getIdtpprodchill();
                    $prodprod = $pratservO->getCdprodproducao();
                }
            }

            foreach ($row['NOVOSPRODUTOS'] as $novosProdutos) {
                $this->prato->insereReceita(
                    $novosProdutos['NRORG'], $cdFilAuxPratoD, $pratoD, $filialD, $servicoD,
                    $novosProdutos['CDPRODUTO'], $novosProdutos['SGUNIDADEPROD'],
                    $novosProdutos['QUANTIDADE'], $novosProdutos['GANHOCOC'],
                    $novosProdutos['PERDALIMP'], $novosProdutos['QTREQUERIDA'],
                    $novosProdutos['QTUNIDEST'], $novosProdutos['APROVNUTRI'],
                    $novosProdutos['QTNUTRI'], $novosProdutos['QTBRUTA'],
                    $novosProdutos['HRTEMP'], $novosProdutos['BASE'],
                    $novosProdutos['QTFIXO'], $novosProdutos['ENTDIR'],
                    $novosProdutos['QTCOMPL'], $novosProdutos['TPREQ'],
                    $novosProdutos['APRESENT'], $novosProdutos['DIASLIM'],
                    $novosProdutos['DIASLIM']
                );
            }

            if ($pratservO){
                $this->prato->insereDadosPrato(
                    $cdFilAuxPratoD, $pratoD, $filialD, $servicoD, $pratservO->getNrcorpriserv(),
                    $pratservO->getNrcorseqserv(), $pratservO->getNrcorauxserv(),
                    $pratservO->getQtpadraoserv(), $pratservO->getQtcontaiserv(),
                    $pratservO->getHrvalconserv(), $pratservO->getNmfantasiase(),
                    $pratservO->getQtcarboprser(), $pratservO->getQtlipidprser(),
                    $pratservO->getQtproteprser(), $pratservO->getQtcalorprser(),
                    $pratservO->getQtalcooprser(), $pratservO->getVrpeminserv(),
                    $pratservO->getQtamostrserv(), $prodprod, $diasLim,
                    $idProdChill, $tpProdChill, $idFinal, $pratservO->getNrorg()
                );
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }


}